<?php
/**
 * Variable product add to cart
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/add-to-cart/variable.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.5.5
 */

defined( 'ABSPATH' ) || die;

global $product;

$attribute_keys  = array_keys( $attributes );
$variations_json = wp_json_encode( $available_variations );
$variations_attr = function_exists( 'wc_esc_json' ) ? wc_esc_json( $variations_json ) : _wp_specialchars( $variations_json, ENT_QUOTES, 'UTF-8', true );

do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="variations_form cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data' data-product_id="<?php echo absint( $product->get_id() ); ?>" data-product_variations="<?php echo esc_attr( $variations_attr ); // WPCS: XSS ok. ?>">
	<?php do_action( 'woocommerce_before_variations_form' ); ?>

	<?php if ( empty( $available_variations ) && false !== $available_variations ) : ?>
		<p class="stock out-of-stock"><?php echo esc_html( apply_filters( 'woocommerce_out_of_stock_message', esc_html__( 'This product is currently out of stock and unavailable.', 'woocommerce' ) ) ); ?></p>
	<?php else : ?>
		<div class="variations">
			<?php foreach ( $attributes as $attribute_name => $options ) : ?>
				<?php
				if ( 'pa_' == substr( $attribute_name, 0, 3 ) ) {
					$attribute_id = wc_attribute_taxonomy_id_by_name( $attribute_name );
				} else {
					$attribute_id = '';
				}
				if ( $attribute_id && ( alpha_get_option( 'advanced_swatch' ) || class_exists( 'Alpha_Plugin_Options' ) && Alpha_Plugin_Options::get_option( 'alpha_advanced_swatch', 'yes' ) ) ) {
					$attribute_type = wc_get_attribute( $attribute_id )->type;
				} else {
					$attribute_type = 'select';
				}
				$class  = '';
				$class .= esc_attr( $attribute_type ) . '-type';
				$class .= ' product-' . esc_attr( $attribute_name ) . '-swatch';
				?>
				<div class="<?php echo esc_attr( $class ); ?>">
					<label><?php echo wc_attribute_label( $attribute_name ); // WPCS: XSS ok. ?>:</label>
					<?php
					if ( 'list' == $attribute_type ) {
						do_action(
							'alpha_wc_product_listed_attributes',
							array(
								$attribute_name => $options,
							)
						);
					}

					wc_dropdown_variation_attribute_options(
						array(
							'options'   => $options,
							'attribute' => $attribute_name,
							'product'   => $product,
							'type'      => $attribute_type,
						)
					);
					?>
				</div>
				<?php
				echo end( $attribute_keys ) == $attribute_name ? alpha_strip_script_tags( apply_filters( 'woocommerce_reset_variations_link', '<div class="reset-variation-cont"><a class="reset_variations d-none" href="#">' . esc_html__( 'Clean All', 'alpha' ) . '</a></div>' ) ) : '';
				?>
			<?php endforeach; ?>
		</div>

		<div class="single_variation_wrap">
			<?php
				/**
				 * Hook: woocommerce_before_single_variation.
				 */
				do_action( 'woocommerce_before_single_variation' );

				/**
				 * Hook: woocommerce_single_variation. Used to output the cart button and placeholder for variation data.
				 *
				 * @since 2.4.0
				 * @hooked woocommerce_single_variation - 10 Empty div for variation data.
				 * @hooked woocommerce_single_variation_add_to_cart_button - 20 Qty and cart button.
				 */
				do_action( 'woocommerce_single_variation' );
				/**
				 * Hook: woocommerce_after_single_variation.
				 */
				do_action( 'woocommerce_after_single_variation' );
			?>
		</div>
	<?php endif; ?>

	<?php do_action( 'woocommerce_after_variations_form' ); ?>
</form>

<?php
do_action( 'woocommerce_after_add_to_cart_form' );
